# neuroproteomics_analysis_tool

[![PyPI - Version](https://img.shields.io/pypi/v/neuroproteomics-analysis-tool.svg)](https://pypi.org/project/neuroproteomics-analysis-tool)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/neuroproteomics-analysis-tool.svg)](https://pypi.org/project/neuroproteomics-analysis-tool)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install neuroproteomics-analysis-tool
```

## License

`neuroproteomics-analysis-tool` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
